@@ -42,8 +42,6 @@ def pause_video(mpv):
     mpv.command("set_property","pause", True)
 
 def play_video(mpv):
-    global stop
-    stop = False
     mpv.command("set_property","pause", False)
 
 def toggle_play(mpv):
@@ -112,16 +110,7 @@ def exit_gracefully():
     send(client_socket, "!DISCONNECT")
 
 def handle_server(server, addr, MPV_PATH):
-    global connected
-    global t_playback
-    global mpv
-    global client_socket
-    global stop
-    global restart
-
     t_playback = 0
-    t_restart = 0
-    restart = 0
     connected = True
 
     operating_system_used = sys.platform
@@ -143,47 +132,15 @@ def handle_server(server, addr, MPV_PATH):
     mpv.command("set_property","keep-open",True)    
     mpv.command("set_property","osd-font-size","18")
 
-
-#    @mpv.property_observer("paused-for-cache")
-#    def observe_playback_time(name, value):
-#        global restart
-#        if value == True:
-#            print("seek = true")
-#            restart+=1
-#            if restart == 4:
-#                restart = 0
-#                restart_url = mpv.command("get_property","path")
-#                skip_time = mpv.command("get_property","playback-time")
-#
-#                send(client_socket, "toggle play")
-#                mpv.play("https://www.youtube.com/watch?v=dQw4w9WgXcQ")
-#               
-#                mpv.play(restart_url)
-#                #ready_when_seeked(mpv, value)
-#                while True:
-#                    seek_bool = mpv.command("get_property","seeking")
-#                    if seek_bool == False:
-#                        pause_video(mpv)
-#                        break
-#                
-#                mpv.command("set_property","playback-time",skip_time)
-#                #new_video(mpv, "https://www.youtube.com/watch?v=dQw4w9WgXcQ")
-                
-
-
     # observe playback-time to synchronize when user skips on timeline 
 
-
-
     @mpv.property_observer("playback-time")
     def observe_playback_time(name, value):  
         global t_playback  
-        global stop
         if value is not None:
             if value > t_playback+0.25 or value < t_playback-0.1:
 
                 if f"mpv skip {value}" != msg:
-                    stop = True
                     t_playback = mpv.command("get_property", "playback-time")
                     print (t_playback)
                     send(client_socket, f"mpv skip {t_playback}")
@@ -195,13 +152,11 @@ def handle_server(server, addr, MPV_PATH):
 
     @mpv.property_observer("path")
     def observe_path(name, value):
-        global stop
         print(name, value)
         if value is not None:
             print (f"New Path: {value}")
             print(msg)
-            if f"mpv new {value}" != msg:   
-                stop = True         
+            if f"mpv new {value}" != msg:       
                 send(client_socket, f"mpv new {value}")
                 new_video(mpv, value)
                 print("READY - PATH OBSERVED")
@@ -211,10 +166,8 @@ def handle_server(server, addr, MPV_PATH):
 
     @mpv.on_key_press("space")
     def toggle_playback():
-        global stop
-        if stop == False:
-            toggle_play(mpv)
-            send(client_socket, "toggle play")
+        toggle_play(mpv)
+        send(client_socket, "toggle play")
 
     # when q is pressed exit gracefully
 
@@ -231,11 +184,9 @@ def handle_server(server, addr, MPV_PATH):
         pause_video(mpv)
         mpv.command('frame-back-step')
 
-
     @mpv.on_key_press(".")
     def frame_step():
         send(client_socket, "frame-step")
-        #pause_video(mpv)
         mpv.command('frame-step')
 
     @mpv.on_key_press("-")
@@ -264,11 +215,69 @@ def handle_server(server, addr, MPV_PATH):
         send(client_socket, "resync")
         ready_when_seeked(mpv, time_pos)
 
+    @mpv.on_key_press("h")
+    def help():
+        mpv.command("show-text", """sync-mpv keybindings
+
+Space           Toggle Play/Pause
+r                    resync clients
++/-                 Speed up/down the video
+.                     Go one frame forwards
+,                     Go one frame backwards
+q                    Quit sync-mpv
+
+Zoom:
+KP 7             Zoom out
+KP 9             Zoom in
+KP 8             Move panorama up
+KP 2             Move panorama down
+KP 4             Move panorama left
+KP 6             Move panorama right
+
+KP 5             Deactivate zoom and go back to normal view mode.
+"""            
+,5000)
+
+    @mpv.on_key_press("kp7")
+    def printest():
+        send(client_socket, "zoom-out")
+        mpv.command('add', 'video-zoom', '-.25')
+
+    @mpv.on_key_press("kp9")
+    def printest():
+        send(client_socket, "zoom-in")
+        mpv.command('add', 'video-zoom', '.25')
+
+    @mpv.on_key_press("kp8")
+    def printest():
+        send(client_socket, "move-up")
+        mpv.command('add', 'video-pan-y', '.05')
+
+    @mpv.on_key_press("kp2")
+    def printest():
+        send(client_socket, "move-down")
+        mpv.command('add', 'video-pan-y', '-.05')
+
+    @mpv.on_key_press("kp4")
+    def printest():
+        send(client_socket, "move-left")
+        mpv.command('add', 'video-pan-x', '.05')
+
+    @mpv.on_key_press("kp6")
+    def printest():
+        send(client_socket, "move-right")
+        mpv.command('add', 'video-pan-x', '-.05')
+
+    @mpv.on_key_press("kp5")
+    def printest():
+        send(client_socket, "reset-window")
+        mpv.command('set', 'video-pan-y', '0')
+        mpv.command('set', 'video-pan-x', '0')
+        mpv.command('set', 'video-zoom', '0')
+
     print(f"[CONNECTION ESTABLISHED] to {addr}")
     
     while connected:
-        global stop
-
         try:
             msg, user = receive_message(server)
 
@@ -277,6 +286,33 @@ def handle_server(server, addr, MPV_PATH):
                     connected = False
                     break
 
+                if msg == "zoom-in":
+                    mpv.command('add', 'video-zoom', '.25')
+                    mpv.command("show-text",f"{user} zooms in.","1500")
+
+                if msg == "zoom-out":
+                    mpv.command('add', 'video-zoom', '-.25')
+                    mpv.command("show-text",f"{user} zooms out.","1500")
+
+                if msg == "move-up":
+                    mpv.command('add', 'video-pan-y', '.05')
+                    mpv.command("show-text",f"{user} zooms in.","1500")
+
+                if msg == "move-down":
+                    mpv.command('add', 'video-pan-y', '-.05')
+
+                if msg == "move-right":
+                    mpv.command('add', 'video-pan-x', '-.05')
+
+                if msg == "move-left":
+                    mpv.command('add', 'video-pan-x', '.05')
+
+                if msg == "reset-window":
+                    mpv.command('set', 'video-pan-y', '0')
+                    mpv.command('set', 'video-pan-x', '0')
+                    mpv.command('set', 'video-zoom', '0')
+                    mpv.command("show-text",f"{user} resets the window.","1500")
+
                 if msg == "frame-step":
                     mpv.command('frame-step')
 
@@ -285,7 +321,6 @@ def handle_server(server, addr, MPV_PATH):
                     speed = mpv.command('get_property','speed')      
                     mpv.command("show-text",f"{user} sets playback-speed to {speed}", "1500")
     
-
                 if msg == 'subtract_speed':
                     mpv.command('add','speed',-0.1)
                     speed = mpv.command('get_property','speed')      
@@ -318,7 +353,6 @@ def handle_server(server, addr, MPV_PATH):
                     mpv.command("show-text",f"{user} toggles", "1500")
 
                 if "mpv skip" in msg:
-                    stop = True
                     t_playback = float(msg.split(" ")[2])
 
                     if t_playback < 3600:
@@ -332,7 +366,6 @@ def handle_server(server, addr, MPV_PATH):
                     ready_when_seeked(mpv, t_playback)
 
                 if "mpv new" in msg:
-                    stop = True
                     videopath = msg[8:]
                     new_video(mpv, videopath)
                     mpv.command("show-text",f"{user}: {videopath}","1500")
@@ -341,7 +374,6 @@ def handle_server(server, addr, MPV_PATH):
                 if "userconnected" in msg:
                     mpv.command("show-text",f"{msg.split(' ')[1]} connected.","1500")
 
-
         except IOError as e:
             if e.errno != errno.EAGAIN and e.errno != errno.EWOULDBLOCK:
                 print(e)
@@ -373,7 +405,6 @@ def parse_config(parser, configfile):
     MPV_PATH = parser.get('connection', 'mpv_path')
     return IP, PORT, USERNAME, PASSWORD, MPV_PATH
 
-
 def initialize(parser, configfile):
     operating_system_used = sys.platform
     IP = input("IP: ")
@@ -393,7 +424,6 @@ def initialize(parser, configfile):
     with open(configfile,"w") as f:
         parser.write(f)
 
-
 def main():
 
     global KEY
@@ -422,10 +452,6 @@ def main():
 
     if not os.path.exists(configfile):
         initialize(parser, configfile)
-        #IP, PORT, USERNAME, PASSWORD, MPV_PATH = parse_config(parser, configfile)
-
-    #else:
-        #initialize(parser, configfile)
 
     IP, PORT, USERNAME, PASSWORD, MPV_PATH = parse_config(parser, configfile)
     
